@@ -394,9 +394,6 @@ DAT_RETURN dapls_ib_open_hca(IN IB_HCA_NAME hca_name,
 #endif
 
 done:
-	/* set default IB MTU */
-	hca_ptr->ib_trans.ib_cm.mtu = dapl_ib_mtu(2048);
-
 	return DAT_SUCCESS;
 }
 
