@@ -58,6 +58,7 @@
 #define DAT_MCM_PDATA_SIZE      64
 #define DAT_MCM_PROXY_DATA	40
 #define DAT_MCM_SEG_PO2		17
+#define DAT_MCM_P2P_INLINE	96
 
 #define ALIGN_64(o)  ((o + 64 - 1) & ~(64-1))
 #define ALIGN_P64(o) ((((uintptr_t)o) + 64 - 1)& ~(64-1))
@@ -233,7 +234,8 @@ typedef struct dat_mcm_msg
 	uint32_t		s_id;  /* src pid */
 	uint32_t		d_id;  /* dst pid */
 	uint8_t			rd_in; /* atomic_rd_in */
-	uint8_t			rsvd[4];
+	uint8_t			mtu;   /* mtu */
+	uint8_t			rsvd[3];
 	uint8_t			seg_sz; /* data segment size in power of 2 */
 	dat_mcm_addr_t		saddr1;	/* QPt local,  MPXY or MCM on non-MIC node */
 	dat_mcm_addr_t		saddr2; /* QPr local,  MIC  or MCM on non-MIC node or MPXY */
@@ -311,6 +313,11 @@ typedef enum dat_mix_ops
 	MIX_PROV_ATTR,
 	MIX_RECV,
 	MIX_CM_REJECT_USER,
+	MIX_PZ_CREATE,
+	MIX_PZ_FREE,
+	MIX_QUERY_DEVICE,
+	MIX_QUERY_PORT,
+	MIX_LAST_OP,	/* Keep last */
 
 } dat_mix_ops_t;
 
@@ -347,8 +354,12 @@ static inline char * mix_op_str(IN int op)
 		"PROV_ATTR",
 		"POST_RECV",
 		"CM_REJECT_USER",
+		"PZ_CREATE",
+		"PZ_FREE",
+		"QUERY_DEVICE",
+		"QUERY_PORT",
 	};
-	return ((op < 2 || op > 28) ? "Invalid OP?" : mix_ops[op]);
+	return ((op < 2 || op >= MIX_LAST_OP) ? "Invalid OP?" : mix_ops[op]);
 }
 
 typedef enum dat_mix_op_flags
@@ -359,6 +370,7 @@ typedef enum dat_mix_op_flags
     MIX_OP_ASYNC  = 0x08,
     MIX_OP_INLINE = 0x10,
     MIX_OP_SET    = 0x20,
+    MIX_OP_MTU    = 0x40,
 
 } dat_mix_op_flags_t;
 
@@ -450,9 +462,88 @@ typedef struct dat_mix_open
 	uint16_t		port;		/* ib physical port number */
 	dat_mix_dev_attr_t	dev_attr;
 	dat_mcm_addr_t		dev_addr;
-
 }  __attribute__((packed)) dat_mix_open_t;
 
+/***** MIX PZ, PZ handle info returned */
+typedef struct dat_mix_pz
+{
+	dat_mix_hdr_t		hdr;
+	uint64_t		ctx;   /* client handle from mic */
+	uint64_t		ib_pd; /* IB PZ handle from proxy */
+}  __attribute__((packed)) dat_mix_pz_t;
+
+/***** MIX QUERY PORT info returned */
+typedef struct dat_mix_port_attr
+{
+	dat_mix_hdr_t           hdr;
+	uint64_t                gid_tbl_len;
+	uint32_t                port_cap_flags;
+	uint32_t                max_msg_sz;
+	uint32_t                bad_pkey_cntr;
+	uint32_t                qkey_viol_cntr;
+	uint16_t                pkey_tbl_len;
+	uint16_t                lid;
+	uint16_t                sm_lid;
+	uint8_t                 lmc;
+	uint8_t                 max_vl_num;
+	uint8_t                 sm_sl;
+	uint8_t                 subnet_timeout;
+	uint8_t                 init_type_reply;
+	uint8_t                 active_width;
+	uint8_t                 active_speed;
+	uint8_t                 phys_state;
+	uint8_t                 link_layer;
+	uint8_t                 state;
+	uint8_t                 max_mtu;
+	uint8_t                 active_mtu;
+}  __attribute__((packed)) dat_mix_port_attr_t;
+
+/***** MIX get,get device attributes, 289 bytes */
+typedef struct dat_mix_device_attr
+{
+dat_mix_hdr_t           hdr;
+	char                    fw_ver[64];
+	uint64_t                node_guid;
+	uint64_t                sys_image_guid;
+	uint64_t                max_mr_size;
+	uint64_t                page_size_cap;
+	uint64_t                max_qp;
+	uint64_t                max_qp_wr;
+	uint64_t                device_cap_flags;
+	uint64_t                max_sge;
+	uint64_t                max_sge_rd;
+	uint64_t                max_cq;
+	uint64_t                max_cqe;
+	uint64_t                max_mr;
+	uint64_t                max_pd;
+	uint64_t                max_qp_rd_atom;
+	uint64_t                max_ee_rd_atom;
+	uint64_t                max_res_rd_atom;
+	uint64_t                max_qp_init_rd_atom;
+	uint64_t                max_ee_init_rd_atom;
+	uint64_t                max_ee;
+	uint64_t                max_rdd;
+	uint64_t                max_mw;
+	uint64_t                max_raw_ipv6_qp;
+	uint64_t                max_raw_ethy_qp;
+	uint64_t                max_mcast_grp;
+	uint64_t                max_mcast_qp_attach;
+	uint64_t                max_total_mcast_qp_attach;
+	uint64_t                max_ah;
+	uint64_t                max_fmr;
+	uint64_t                max_map_per_fmr;
+	uint64_t                max_srq;
+	uint64_t                max_srq_wr;
+	uint64_t                max_srq_sge;
+	uint32_t                vendor_id;
+	uint32_t                vendor_part_id;
+	uint32_t                hw_ver;
+	uint16_t                max_pkeys;
+	uint8_t                 local_ca_ack_delay;
+	uint8_t                 phys_port_cnt;
+	uint8_t                 atomic_cap;
+}  __attribute__((packed)) dat_mix_device_attr_t;
+
 /***** MIX get,set attributes, 128 bytes */
 typedef struct dat_mix_attr
 {
@@ -755,6 +846,7 @@ enum mcm_wr_flags {
 
 	M_READ_FROM_DONE	= 1 << 16, /* m_wr mpxyd read_from_done, ready for posting */
 	M_SEND_DIRECT		= 1 << 17, /* m_wr SEND direct from host memory, no proxy out buffer */
+	M_PROXY_INLINE		= 1 << 18, /* m_wr contains the data */
 };
 
 /* 80 bytes */
@@ -793,7 +885,7 @@ typedef struct mcm_wrc_info {
 	uint16_t	wc_end;
 } __attribute__((packed)) mcm_wrc_info_t;
 
-/* WR: 160 bytes, direct RDMA write from remote Proxy-in service */
+/* WR: 256 bytes, direct RDMA write from remote Proxy-in service */
 typedef struct mcm_wr_rx {
 	struct dat_mix_wr	wr;
 	struct dat_mix_sge   	sg[DAT_MIX_SGE_MAX];
@@ -805,8 +897,11 @@ typedef struct mcm_wr_rx {
 	uint32_t		flags;
 	uint32_t		time;
 	uint32_t		qcnt;
+	char			inline_data[DAT_MCM_P2P_INLINE];
 } __attribute__((packed)) mcm_wr_rx_t;
 
+#define MCM_WR_RX_NO_DATA	(sizeof(mcm_wr_rx_t) - DAT_MCM_P2P_INLINE)
+
 /* WC: 80 bytes, direct RDMA write from remote Proxy-in service */
 typedef struct mcm_wc_rx {
 	struct dat_mix_wc	wc;
@@ -826,14 +921,14 @@ static inline void mcm_hton_wrc(mcm_wrc_info_t *dst, mcm_wrc_info_t *src)
 	if (src->wr_addr) {
 		dst->wr_addr = htonll(src->wr_addr);
 		dst->wr_rkey = htonl(src->wr_rkey);
-		dst->wr_len = htons(src->wr_len);
+		dst->wr_len = htonl(src->wr_len);
 		dst->wr_sz = htons(src->wr_sz);
 		dst->wr_end = htons(src->wr_end);
 	}
 	if (src->wc_addr) {
 		dst->wc_addr = htonll(src->wc_addr);
 		dst->wc_rkey = htonl(src->wc_rkey);
-		dst->wc_len = htons(src->wc_len);
+		dst->wc_len = htonl(src->wc_len);
 		dst->wc_sz = htons(src->wc_sz);
 		dst->wc_end = htons(src->wc_end);
 	}
@@ -844,13 +939,13 @@ static inline void mcm_ntoh_wrc(mcm_wrc_info_t *dst, mcm_wrc_info_t *src)
 {
 	dst->wr_addr = ntohll(src->wr_addr);
 	dst->wr_rkey = ntohl(src->wr_rkey);
-	dst->wr_len = ntohs(src->wr_len);
+	dst->wr_len = ntohl(src->wr_len);
 	dst->wr_sz = ntohs(src->wr_sz);
 	dst->wr_end = ntohs(src->wr_end);
 
 	dst->wc_addr = ntohll(src->wc_addr);
 	dst->wc_rkey = ntohl(src->wc_rkey);
-	dst->wc_len = ntohs(src->wc_len);
+	dst->wc_len = ntohl(src->wc_len);
 	dst->wc_sz = ntohs(src->wc_sz);
 	dst->wc_end = ntohs(src->wc_end);
 }
@@ -860,7 +955,7 @@ static inline void mcm_hton_wr_rx(struct mcm_wr_rx *m_wr_rx, struct mcm_wr *m_wr
 {
 	int i;
 
-	memset((void*)m_wr_rx, 0, sizeof(*m_wr_rx));
+	memset((void*)m_wr_rx, 0, MCM_WR_RX_NO_DATA);
 	m_wr_rx->org_id = (uint64_t) htonll((uint64_t)m_wr); /* proxy_out WR */
 	m_wr_rx->flags = htonl(m_wr->flags);
 	m_wr_rx->w_idx = htonl(wc_tl); /* snd back wc tail */
