@@ -343,6 +343,18 @@ const char *dapl_ib_port_num_str(unsigned long num)
 	}
 }
 
+const char *dapl_ib_gid_str(union ibv_gid *gid, char *str)
+{
+	sprintf(str, "%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x",
+		gid->raw[0], gid->raw[1], gid->raw[2], gid->raw[3],
+		gid->raw[4], gid->raw[5], gid->raw[6], gid->raw[7],
+		gid->raw[8], gid->raw[9], gid->raw[10],gid->raw[11],
+		gid->raw[12],gid->raw[13],gid->raw[14],gid->raw[15]);
+
+	return str;
+}
+
+
 /*
  * dapls_ib_query_hca
  *
@@ -370,6 +382,7 @@ DAT_RETURN dapls_ib_query_hca(IN DAPL_HCA * hca_ptr,
 	ib_hca_transport_t *tp = &hca_ptr->ib_trans;
 	struct ibv_device_attr dev_attr;
 	struct ibv_port_attr port_attr;
+	union ibv_gid port_gid;
 
 	/* local IP address of device, set during ia_open */
 	if (ip_addr)
@@ -424,13 +437,6 @@ DAT_RETURN dapls_ib_query_hca(IN DAPL_HCA * hca_ptr,
 	dev_attr.max_qp_wr = DAPL_MIN(dev_attr.max_qp_wr,
 				      dapl_os_get_env_val("DAPL_WR_MAX", dev_attr.max_qp_wr));
 
-	/* MTU to active by default, reset if env set and <= active_mtu */
-	if (getenv("DAPL_IB_MTU"))
-		tp->ib_cm.mtu = DAPL_MIN(port_attr.active_mtu,
-					 dapl_ib_mtu(dapl_os_get_env_val("DAPL_IB_MTU", DCM_IB_MTU)));
-	else
-		tp->ib_cm.mtu = port_attr.active_mtu;
-
 #ifdef _OPENIB_MCM_
 	/* Adjust for CCL Proxy; limited sge's, no READ support, reduce QP and RDMA limits */
 	dev_attr.max_sge = DAPL_MIN(dev_attr.max_sge, DAT_MIX_SGE_MAX);
@@ -438,6 +444,13 @@ DAT_RETURN dapls_ib_query_hca(IN DAPL_HCA * hca_ptr,
 				      dapl_os_get_env_val("DAPL_MCM_WR_MAX", DAT_MIX_WR_MAX));
 	port_attr.max_msg_sz = DAPL_MIN(port_attr.max_msg_sz,
 					dapl_os_get_env_val("DAPL_MCM_MSG_MAX", DAT_MIX_RDMA_MAX));
+#else
+	/* MTU to active by default, reset if env set and <= active_mtu */
+	if (getenv("DAPL_IB_MTU"))
+		tp->ib_cm.mtu = DAPL_MIN(port_attr.active_mtu,
+					 dapl_ib_mtu(dapl_os_get_env_val("DAPL_IB_MTU", DCM_IB_MTU)));
+	else
+		tp->ib_cm.mtu = port_attr.active_mtu;
 #endif
 
 	if (ia_attr != NULL) {
@@ -498,19 +511,21 @@ DAT_RETURN dapls_ib_query_hca(IN DAPL_HCA * hca_ptr,
 		ia_attr->num_vendor_attr = 0;
 		ia_attr->vendor_attr = NULL;
 #ifdef DAT_EXTENSIONS
+		ia_attr->extension_supported = DAT_EXTENSION_IB;
+		ia_attr->extension_version = DAT_IB_EXTENSION_VERSION;
+		tp->na.ib_ext = "TRUE";
+		tp->na.i_data = "TRUE";
+		tp->na.f_add  = "TRUE";
+		tp->na.c_swap = "TRUE";
+#ifdef _OPENIB_MCM_
+		if (!MXF_EP(&hca_ptr->ib_trans.addr))
+#endif
 		if (hca_ptr->ib_hca_handle->device->transport_type == IBV_TRANSPORT_IWARP) {
 			ia_attr->extension_supported = DAT_EXTENSION_NONE;
 			tp->na.ib_ext = "FALSE";
 			tp->na.i_data = "FALSE";
 			tp->na.f_add  = "FALSE";
 			tp->na.c_swap = "FALSE";
-		} else {
-			ia_attr->extension_supported = DAT_EXTENSION_IB;
-			ia_attr->extension_version = DAT_IB_EXTENSION_VERSION;
-			tp->na.ib_ext = "TRUE";
-			tp->na.i_data = "TRUE";
-			tp->na.f_add  = "TRUE";
-			tp->na.c_swap = "TRUE";
 		}
 #endif
 		/* save key device attributes for CM exchange */
@@ -523,20 +538,28 @@ DAT_RETURN dapls_ib_query_hca(IN DAPL_HCA * hca_ptr,
 		tp->na.mtu = dapl_ib_mtu_str(tp->ib_cm.mtu);
 		tp->na.port = dapl_ib_port_str(port_attr.state);
 		tp->na.port_num = dapl_ib_port_num_str(hca_ptr->port_num);
-		if (!tp->guid) {
+
+		if (!tp->na.gid) {
 #ifdef _OPENIB_MCM_
-			if (MFO_EP(&hca_ptr->ib_trans.addr) && tp->self.node)
+			if (MFO_EP(&hca_ptr->ib_trans.addr) && tp->self.node) {
 				tp->guid = ntohll(dev_attr.node_guid);
+				memcpy(&port_gid, tp->addr.gid, sizeof(port_gid));
+			}
 			else
 #endif
+			{
 				tp->guid = ntohll(ibv_get_device_guid(tp->ib_dev));
-		}
+				/* get gid and init named attribute */
+				ibv_query_gid(hca_ptr->ib_hca_handle, (uint8_t)hca_ptr->port_num, 0, &port_gid);
+			}
 
-		sprintf(tp->guid_str, "%04x:%04x:%04x:%04x",
-			(unsigned) (tp->guid >> 48) & 0xffff,
-			(unsigned) (tp->guid >> 32) & 0xffff,
-			(unsigned) (tp->guid >> 16) & 0xffff,
-			(unsigned) (tp->guid >>  0) & 0xffff);
+			tp->na.gid = dapl_ib_gid_str(&port_gid, tp->gid_str);
+			sprintf(tp->guid_str, "%04x:%04x:%04x:%04x",
+				(unsigned) (tp->guid >> 48) & 0xffff,
+				(unsigned) (tp->guid >> 32) & 0xffff,
+				(unsigned) (tp->guid >> 16) & 0xffff,
+				(unsigned) (tp->guid >>  0) & 0xffff);
+		}
 
 #ifdef _OPENIB_MCM_
 		/* initialized at open */
@@ -833,6 +856,9 @@ DAT_NAMED_ATTR ib_attrs[] = {
 	{
 	 "DAT_IB_NODE_GUID", "xxxx:xxxx:xxxx:xxxx"}
 	,
+	{
+	 "DAT_IB_GID", "xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx"}
+	,
 	{
 	 "DAT_IB_TRANSPORT_MTU", "2048"}
 	,
@@ -924,6 +950,8 @@ void dapls_query_provider_specific_attr(IN DAPL_IA * ia_ptr,
 			ib_attrs[i].value = ia_ptr->hca_ptr->ib_trans.na.read;
 		else if (!strcmp(ib_attrs[i].name, "DAT_IB_NODE_GUID"))
 			ib_attrs[i].value = ia_ptr->hca_ptr->ib_trans.guid_str;
+		else if (!strcmp(ib_attrs[i].name, "DAT_IB_GID"))
+			ib_attrs[i].value = ia_ptr->hca_ptr->ib_trans.na.gid;
 		else if (!strcmp(ib_attrs[i].name, "DAT_IB_TRANSPORT_MTU"))
 			ib_attrs[i].value = ia_ptr->hca_ptr->ib_trans.na.mtu;
 		else if (!strcmp(ib_attrs[i].name, "DAT_IB_PORT_STATUS"))
