@@ -171,8 +171,13 @@ int dapli_mix_open(ib_hca_transport_t *tp, char *name, int port, int query_only)
 	msg.port = port;
 	strcpy((char*)&msg.name, name);
 
-	if (getenv("DAPL_IB_MTU"))
+	if (getenv("DAPL_IB_MTU")) {
 		msg.hdr.flags |= MIX_OP_MTU;
+		msg.dev_attr.mtu = tp->ib_cm.mtu; /* set to env value */
+	} else {
+		msg.hdr.flags |= MIX_OP_SET; /* ok for proxy to set MTU */
+		msg.dev_attr.mtu = IBV_MTU_2048; /* compat mode */
+	}
 
 	/* send any overridden attributes to proxy */
 	msg.dev_attr.ack_timer = tp->ib_cm.ack_timer;
@@ -183,7 +188,6 @@ int dapli_mix_open(ib_hca_transport_t *tp, char *name, int port, int query_only)
 	msg.dev_attr.hop_limit = tp->ib_cm.hop_limit;
 	msg.dev_attr.tclass = tp->ib_cm.tclass;
 	msg.dev_attr.sl = tp->ib_cm.sl;
-	msg.dev_attr.mtu = tp->ib_cm.mtu;
 	msg.dev_attr.rd_atom_in = tp->ib_cm.rd_atom_in;
 	msg.dev_attr.rd_atom_out = tp->ib_cm.rd_atom_out;
 	msg.dev_attr.pkey_idx = tp->ib_cm.pkey_idx;
@@ -237,6 +241,7 @@ int dapli_mix_open(ib_hca_transport_t *tp, char *name, int port, int query_only)
 	tp->ib_cm.pkey_idx = msg.dev_attr.pkey_idx;
 	tp->ib_cm.pkey = msg.dev_attr.pkey;
 	tp->ib_cm.max_inline = msg.dev_attr.max_inline;
+	tp->ib_cm.mtu = msg.dev_attr.mtu; /* proxy sets active_MTU mode */
 	tp->dev_id = msg.hdr.req_id;
 
 	if (MFO_EP(&tp->addr))
