@@ -371,8 +371,6 @@ DAT_RETURN dapls_ib_open_hca(IN IB_HCA_NAME hca_name,
 	    dapl_os_get_env_val("DAPL_HOP_LIMIT", SCM_HOP_LIMIT);
 	hca_ptr->ib_trans.ib_cm.tclass =
 	    dapl_os_get_env_val("DAPL_TCLASS", SCM_TCLASS);
-	hca_ptr->ib_trans.ib_cm.mtu =
-	    dapl_ib_mtu(dapl_os_get_env_val("DAPL_IB_MTU", SCM_IB_MTU));
 
 	if (flags & DAPL_OPEN_QUERY)
 		goto done;
