@@ -67,7 +67,7 @@ extern int mcm_cpu_model;
 static void mix_get_prov_attr(mcm_scif_dev_t *smd, dat_mix_prov_attr_t *pr_attr)
 {
 	memset(pr_attr, 0, sizeof(dat_mix_prov_attr_t));
-	memcpy(&pr_attr->dev_attr, &smd->md->dev_attr, sizeof(dat_mix_dev_attr_t));
+	memcpy(&pr_attr->dev_attr, &smd->dev_attr, sizeof(dat_mix_dev_attr_t));
 
 	mcm_get_attr(pr_attr);  /* CM attributes */
 	pr_attr->max_msg_sz = mix_max_msg_mb * 1024 * 1024;
@@ -1642,8 +1642,8 @@ int mix_cm_rep_in(mcm_cm_t *m_cm, dat_mcm_msg_t *pkt, int pkt_len)
 
 	/* Set QP MTU, if negotiated. 2K for compatibility */
 	m_cm->m_qp->mtu = pkt->mtu ?
-			  min(pkt->mtu, m_cm->md->dev_attr.mtu):
-			  m_cm->md->mtu_env ? m_cm->md->mtu_env : IBV_MTU_2048;
+			  min(pkt->mtu, m_cm->smd->dev_attr.mtu):
+			  m_cm->smd->mtu_env ? m_cm->smd->mtu_env : IBV_MTU_2048;
 	m_cm->msg.mtu = m_cm->m_qp->mtu; /* forward negotiated MTU */
 
 	mlog(2, " WRC: m_qp %p - WR 0x%Lx rkey 0x%x ln %d, sz %d end %d"
@@ -1821,7 +1821,7 @@ int mix_cm_req_in(mcm_cm_t *cm, dat_mcm_msg_t *pkt, int pkt_len)
 		 mcm_map_str(acm->msg.daddr2.ep_map),
 		 acm->md->addr.lid == acm->msg.daddr1.lid ? "platform":"fabric",
 		 ntohll(acm->msg.sys_guid), &msg, sizeof(dat_mcm_msg_t),
-		 cm->md->dev_attr.mtu, pkt->mtu);
+		 cm->smd->dev_attr.mtu, pkt->mtu);
 
 	if (pkt->p_size)
 		memcpy(acm->msg.p_data, pkt->p_data, ntohs(pkt->p_size));
@@ -2109,8 +2109,8 @@ static int mix_cm_rep_out(mcm_scif_dev_t *smd, dat_mix_cm_t *pmsg, scif_epd_t sc
 
 	/* Set QP MTU, if negotiated. 2K for compatibility */
 	m_cm->m_qp->mtu = m_cm->msg.mtu ?
-			  min(m_cm->msg.mtu, m_cm->md->dev_attr.mtu):
-			  m_cm->md->mtu_env ? m_cm->md->mtu_env : IBV_MTU_2048;
+			  min(m_cm->msg.mtu, smd->dev_attr.mtu):
+			  smd->mtu_env ? smd->mtu_env : IBV_MTU_2048;
 
 	if (qp) {
 		if (mcm_modify_qp(qp, IBV_QPS_RTR, dqpn, dlid, dgid))
