@@ -229,7 +229,7 @@ static struct ibv_context *open_ib_device(struct mcm_ib_dev *md, char *name, int
 					ibctx = NULL;
 					goto bail;
 				}
-
+				md->dev_attr.mtu = port_attr.active_mtu;
 				md->dev_attr.rd_atom_in = device_attr.max_qp_rd_atom;
 				md->dev_attr.rd_atom_out = device_attr.max_qp_init_rd_atom;
 				md->ibdev = iblist[i];
@@ -788,10 +788,23 @@ found:
 	msg->hdr.status = MIX_SUCCESS;
 	msg->dev_attr.rd_atom_in = md->dev_attr.rd_atom_in;
 	msg->dev_attr.rd_atom_out = md->dev_attr.rd_atom_out;
+
+	/* MIC side changed MTU via DAPL_IB_MTU, cover new and old clients */
+	if ((msg->hdr.flags & MIX_OP_MTU) ||
+	    (msg->dev_attr.mtu != IBV_MTU_2048)) {
+		smd->mtu_env = msg->dev_attr.mtu;
+		smd->dev_attr.mtu = msg->dev_attr.mtu; /* set new MTU per MIC */
+	} else if (msg->hdr.flags & MIX_OP_SET) {
+		smd->dev_attr.mtu = md->dev_attr.mtu; /* MIC set to active_MTU */
+	} else {
+		smd->dev_attr.mtu = IBV_MTU_2048; /* run compat_mode */
+	}
+	msg->dev_attr.mtu = smd->dev_attr.mtu; /* return MTU settings */
+
 	if (!(mcm_ib_inline_data(md->ibctx))  || !mcm_ib_inline)
 		msg->dev_attr.max_inline = 0;
 
-	memcpy(&md->dev_attr, &msg->dev_attr, sizeof(dat_mix_dev_attr_t));
+	memcpy(&smd->dev_attr, &msg->dev_attr, sizeof(dat_mix_dev_attr_t)); /* save to smd */
 	memcpy(&msg->dev_addr, &md->addr, sizeof(dat_mcm_addr_t)); /* proxy CM lid */
 
 	/* intra-node: restore MIC lid, gid */
@@ -799,10 +812,6 @@ found:
 		msg->dev_addr.lid = md->m_lid;
 		memcpy(msg->dev_addr.gid, md->m_gid, 16);
 	}
-
-	/* MTU changed via DAPL_IB_MTU */
-	if (msg->hdr.flags & MIX_OP_MTU)
-		md->mtu_env = md->dev_attr.mtu;
 err:
 	if (!smd) {
 		mlog(1, " WARN: open failed for %s - %d\n", msg->name, msg->port);
@@ -825,7 +834,8 @@ err:
 	mlog(1, " MIC client: mdev[%d] %p->%p mic%d[%d] -> %s[%d] port %d lid %x %s mtu %d (%d)\n",
 		md->smd_list.tid, md, smd, mc->scif_id-1, mc->numa_node, msg->name,
 		md->numa_node, msg->port, ntohs(msg->dev_addr.lid), mcm_map_str(md->addr.ep_map),
-		md->dev_attr.mtu, md->mtu_env);
+		smd ? smd->dev_attr.mtu:md->dev_attr.mtu,
+		smd ? smd->mtu_env:0);
 bail:
 	mpxy_unlock(&mc->oplock);
 	mpxy_unlock(&mc->cmlock);
