@@ -132,7 +132,6 @@ typedef struct mcm_ib_dev {
 	int 			numa_node;
 	int			indata;
 	void			*cntrs;
-	uint8_t			mtu_env;
 
 } mcm_ib_dev_t;
 
@@ -369,6 +368,8 @@ typedef struct mcm_scif_dev {
 	int			m_buf_hd_r;	/* Proxy Buffer WC queue hd */
 	int			m_buf_end_r;	/* Proxy Buffer WC queue end */
 	char			*cmd_buf;	/* operation command buffer  */
+	struct dat_mix_dev_attr	dev_attr;	/* Manage attributes per MIC client open */
+	uint8_t			mtu_env;	/* mtu override with DAPL_IB_MTU */
 #ifdef MCM_PROFILE
 	uint16_t		m_hd_ro;	/* HD,TL tracking */
 	uint16_t		m_tl_ro;
