@@ -166,12 +166,11 @@ static DAT_RMR_TRIPLET *p_rmr_rcv;
 static DAT_RMR_TRIPLET *p_rmr_snd;
 
 /* rdma pointers */
-char *rbuf = NULL;
-char *sbuf = NULL;
-int status;
+static char *rbuf = NULL;
+static char *sbuf = NULL;
 
 /* timers */
-double start, stop, total_us, total_sec;
+static double start, stop;
 
 struct dt_time {
 	double total;
@@ -194,7 +193,7 @@ struct dt_time {
 	double conn;
 };
 
-struct dt_time ts;
+static struct dt_time ts;
 
 /* defaults */
 static int all_data_sizes = 0;
@@ -233,28 +232,29 @@ static int data_check = 0;
 /* forward prototypes */
 const char *DT_RetToStr(DAT_RETURN ret_value);
 const char *DT_EventToStr(DAT_EVENT_NUMBER event_code);
-void print_usage(void);
-double get_time(void);
-void init_data(void);
 
-DAT_RETURN send_msg(void *data,
+static void print_usage(void);
+static double get_time(void);
+static void init_data(void);
+
+static DAT_RETURN send_msg(void *data,
 		    DAT_COUNT size,
 		    DAT_LMR_CONTEXT context,
 		    DAT_DTO_COOKIE cookie, DAT_COMPLETION_FLAGS flags);
 
-DAT_RETURN connect_ep(char *hostname,
+static DAT_RETURN connect_ep(char *hostname,
 		      DAT_CONN_QUAL conn_id,
 		      struct sockaddr *ser_sa);
-void disconnect_ep(void);
-DAT_RETURN register_rdma_memory(void);
-DAT_RETURN unregister_rdma_memory(void);
-DAT_RETURN create_events(void);
-DAT_RETURN destroy_events(void);
-DAT_RETURN do_rdma_write_imm_with_msg(void);
-DAT_RETURN do_rdma_write_with_msg(void);
-DAT_RETURN do_rdma_write_ping_pong(int p2, int bytes);
-DAT_RETURN do_rdma_read_with_msg(void);
-DAT_RETURN do_ping_pong_msg(void);
+static void disconnect_ep(void);
+static DAT_RETURN register_rdma_memory(void);
+static DAT_RETURN unregister_rdma_memory(void);
+static DAT_RETURN create_events(void);
+static DAT_RETURN destroy_events(void);
+static DAT_RETURN do_rdma_write_imm_with_msg(void);
+static DAT_RETURN do_rdma_write_with_msg(void);
+static DAT_RETURN do_rdma_write_ping_pong(int p2, int bytes);
+static DAT_RETURN do_rdma_read_with_msg(void);
+static DAT_RETURN do_ping_pong_msg(void);
 
 #define LOGPRINTF if (verbose) printf
 #define CONN_PORT 15828
@@ -262,7 +262,7 @@ DAT_RETURN do_ping_pong_msg(void);
 /* The Format of the message we pass through sockets */
 #define CONN_MSG_FMT "%04hx:%08x:%08x:%08x:%s"
 
-void flush_evds(void)
+static void flush_evds(void)
 {
 	DAT_EVENT event;
 
@@ -359,7 +359,7 @@ static void print_ia_address(struct sockaddr *sa)
 	}
 }
 
-int conn_client_connect(const char *servername, int port)
+static int conn_client_connect(const char *servername, int port)
 {
 
 	struct addrinfo *res, *t;
@@ -402,7 +402,7 @@ int conn_client_connect(const char *servername, int port)
 	return sockfd;
 }
 
-int conn_server_connect(int port)
+static int conn_server_connect(int port)
 {
 	struct addrinfo *res, *t;
 	struct addrinfo hints = {
@@ -1129,7 +1129,7 @@ finish:
 	return (0);
 }
 
-double get_time(void)
+static double get_time(void)
 {
 	struct timeval tp;
 
@@ -1137,13 +1137,13 @@ double get_time(void)
 	return ((double)tp.tv_sec + (double)tp.tv_usec * 1e-6);
 }
 
-void init_data(void)
+static void init_data(void)
 {
 	memset(rbuf, 'a', buf_len);
 	memset(sbuf, 'b', buf_len);
 }
 
-DAT_RETURN
+static DAT_RETURN
 send_msg(void *data,
 	 DAT_COUNT size,
 	 DAT_LMR_CONTEXT context,
@@ -1202,7 +1202,7 @@ send_msg(void *data,
 
 		}
 		if (event.event_data.dto_completion_event_data.status !=
-		    DAT_SUCCESS) {
+		    DAT_DTO_SUCCESS) {
 			fprintf(stderr, "%d: ERROR: DTO event status %s\n",
 				getpid(), DT_RetToStr(ret));
 			return (DAT_ABORT);
@@ -1212,6 +1212,7 @@ send_msg(void *data,
 	return DAT_SUCCESS;
 }
 
+static
 DAT_RETURN connect_ep(char *hostname,
 		      DAT_CONN_QUAL conn_id,
 		      struct sockaddr *ser_sa)
@@ -1609,7 +1610,7 @@ no_resolution:
 	return (DAT_SUCCESS);
 }
 
-void disconnect_ep(void)
+static void disconnect_ep(void)
 {
 	DAT_RETURN ret;
 	DAT_EVENT event;
@@ -1695,7 +1696,7 @@ void disconnect_ep(void)
 	return;
 }
 
-DAT_RETURN do_rdma_write_with_msg(void)
+static DAT_RETURN do_rdma_write_with_msg(void)
 {
 	DAT_EVENT event;
 	DAT_DTO_COMPLETION_EVENT_DATA *dto_event;
@@ -1862,7 +1863,7 @@ acked:
 	return (DAT_SUCCESS);
 }
 
-DAT_RETURN do_rdma_write_imm_with_msg(void)
+static DAT_RETURN do_rdma_write_imm_with_msg(void)
 {
 	DAT_EVENT event;
 	DAT_LMR_TRIPLET l_iov[MSG_IOV_COUNT];
@@ -2041,9 +2042,9 @@ acked:
 }
 
 #define PAT_NUM 5
-unsigned char pat[PAT_NUM] = { 0, 0xff, 0x55, 0xaa, 0 };
+static unsigned char pat[PAT_NUM] = { 0, 0xff, 0x55, 0xaa, 0 };
 
-void set_pat(unsigned int len, unsigned int pat_num)
+static void set_pat(unsigned int len, unsigned int pat_num)
 {
 	if (len <= 1)
 		return;
@@ -2089,7 +2090,7 @@ void set_pat(unsigned int len, unsigned int pat_num)
 
 
 /* always uni-direction */
-DAT_RETURN do_rdma_write_ping_pong(int p2, int bytes)
+static DAT_RETURN do_rdma_write_ping_pong(int p2, int bytes)
 {
 	DAT_EVENT event;
 	DAT_LMR_TRIPLET l_iov[MSG_IOV_COUNT];
@@ -2215,7 +2216,7 @@ DAT_RETURN do_rdma_write_ping_pong(int p2, int bytes)
 	return (DAT_SUCCESS);
 }
 
-DAT_RETURN do_rdma_read_with_msg(void)
+static DAT_RETURN do_rdma_read_with_msg(void)
 {
 	DAT_EVENT event;
 	DAT_LMR_TRIPLET l_iov;
@@ -2287,7 +2288,7 @@ DAT_RETURN do_rdma_read_with_msg(void)
 			return (DAT_ABORT);
 		}
 		if (event.event_data.dto_completion_event_data.status !=
-		    DAT_SUCCESS) {
+		    DAT_DTO_SUCCESS) {
 			fprintf(stderr, "%d: ERROR: DTO event status %s\n",
 				getpid(), DT_RetToStr(ret));
 			return (DAT_ABORT);
@@ -2385,7 +2386,7 @@ DAT_RETURN do_rdma_read_with_msg(void)
 	return (DAT_SUCCESS);
 }
 
-DAT_RETURN do_ping_pong_msg()
+static DAT_RETURN do_ping_pong_msg()
 {
 	DAT_EVENT event;
 	DAT_DTO_COOKIE cookie;
@@ -2540,7 +2541,7 @@ DAT_RETURN do_ping_pong_msg()
 }
 
 /* Register RDMA Receive buffer */
-DAT_RETURN register_rdma_memory(void)
+static DAT_RETURN register_rdma_memory(void)
 {
 	DAT_RETURN ret;
 	DAT_REGION_DESCRIPTION region;
@@ -2600,7 +2601,7 @@ DAT_RETURN register_rdma_memory(void)
 /*
  * Unregister RDMA memory
  */
-DAT_RETURN unregister_rdma_memory(void)
+static DAT_RETURN unregister_rdma_memory(void)
 {
 	DAT_RETURN ret;
 
@@ -2641,7 +2642,7 @@ DAT_RETURN unregister_rdma_memory(void)
  /*
   * Create CNO, CR, CONN, and DTO events
   */
-DAT_RETURN create_events(void)
+static DAT_RETURN create_events(void)
 {
 	DAT_RETURN ret;
 	DAT_EVD_PARAM param;
@@ -2751,7 +2752,7 @@ DAT_RETURN create_events(void)
  * Destroy CR, CONN, CNO, and DTO events
  */
 
-DAT_RETURN destroy_events(void)
+static DAT_RETURN destroy_events(void)
 {
 	DAT_RETURN ret;
 
@@ -2839,7 +2840,7 @@ DAT_RETURN destroy_events(void)
  * Map DAT_RETURN values to readable strings,
  * but don't assume the values are zero-based or contiguous.
  */
-char errmsg[512] = { 0 };
+static char errmsg[512] = { 0 };
 const char *DT_RetToStr(DAT_RETURN ret_value)
 {
 	const char *major_msg, *minor_msg;
@@ -2894,7 +2895,7 @@ const char *DT_EventToStr(DAT_EVENT_NUMBER event_code)
 	return ("Invalid_DAT_EVENT_NUMBER");
 }
 
-void print_usage(void)
+static void print_usage(void)
 {
 	printf("\n DAPL USAGE \n\n");
 	printf("s: server\n");
