@@ -69,7 +69,7 @@
 #include "dat2/udat.h"
 #include "dat2/dat_ib_extensions.h"
 
-int disconnect_ep(void);
+static int disconnect_ep(void);
 
 #define _OK(status, str) \
 {\
@@ -146,41 +146,40 @@ int disconnect_ep(void);
 #define MAX_EP_COUNT		1000
 #define MAX_AH_COUNT		(MAX_EP_COUNT * 2)
 
-DAT_VADDR *atomic_buf;
-DAT_LMR_HANDLE lmr_atomic;
-DAT_LMR_CONTEXT lmr_atomic_context;
-DAT_RMR_CONTEXT rmr_atomic_context;
-DAT_VLEN reg_atomic_size;
-DAT_VADDR reg_atomic_addr;
-DAT_LMR_HANDLE lmr[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_LMR_CONTEXT lmr_context[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_RMR_TRIPLET rmr[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_RMR_CONTEXT rmr_context[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_VLEN reg_size[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_VADDR reg_addr[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_RMR_TRIPLET *buf[REG_MEM_COUNT * MAX_EP_COUNT];
-DAT_EP_HANDLE ep[MAX_EP_COUNT];
-DAT_EVD_HANDLE async_evd = DAT_HANDLE_NULL;
-DAT_IA_HANDLE ia = DAT_HANDLE_NULL;
-DAT_PZ_HANDLE pz = DAT_HANDLE_NULL;
-DAT_EVD_HANDLE cr_evd = DAT_HANDLE_NULL;
-DAT_EVD_HANDLE con_evd = DAT_HANDLE_NULL;
-DAT_EVD_HANDLE dto_evd = DAT_HANDLE_NULL;
-DAT_PSP_HANDLE psp = DAT_HANDLE_NULL;
-int server = 1;
-int remote_host = 0;
-int ud_test = 0;
-int multi_eps = 0;
-int buf_size = BUF_SIZE;
-int msg_size = sizeof(DAT_RMR_TRIPLET);
-char provider[64] = DAPL_PROVIDER;
-char hostname[256] = { 0 };
+static DAT_VADDR *atomic_buf;
+static DAT_LMR_HANDLE lmr_atomic;
+static DAT_LMR_CONTEXT lmr_atomic_context;
+static DAT_RMR_CONTEXT rmr_atomic_context;
+static DAT_VLEN reg_atomic_size;
+static DAT_VADDR reg_atomic_addr;
+static DAT_LMR_HANDLE lmr[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_LMR_CONTEXT lmr_context[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_RMR_CONTEXT rmr_context[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_VLEN reg_size[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_VADDR reg_addr[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_RMR_TRIPLET *buf[REG_MEM_COUNT * MAX_EP_COUNT];
+static DAT_EP_HANDLE ep[MAX_EP_COUNT];
+static DAT_EVD_HANDLE async_evd = DAT_HANDLE_NULL;
+static DAT_IA_HANDLE ia = DAT_HANDLE_NULL;
+static DAT_PZ_HANDLE pz = DAT_HANDLE_NULL;
+static DAT_EVD_HANDLE cr_evd = DAT_HANDLE_NULL;
+static DAT_EVD_HANDLE con_evd = DAT_HANDLE_NULL;
+static DAT_EVD_HANDLE dto_evd = DAT_HANDLE_NULL;
+static DAT_PSP_HANDLE psp = DAT_HANDLE_NULL;
+static int server = 1;
+static int remote_host = 0;
+static int ud_test = 0;
+static int multi_eps = 0;
+static int buf_size = BUF_SIZE;
+static int msg_size = sizeof(DAT_RMR_TRIPLET);
+static char provider[64] = DAPL_PROVIDER;
+static char hostname[256] = { 0 };
 static DAT_IB_ADDR_HANDLE remote_ah[MAX_EP_COUNT][MAX_AH_COUNT];
-int eps = 1;
-int verbose = 0;
-int counters = 0;
-int counters_ok = 0;
-int query_only = 0;
+static int eps = 1;
+static int verbose = 0;
+static int counters = 0;
+static int counters_ok = 0;
+static int query_only = 0;
 static int ucm = 0;
 static DAT_SOCK_ADDR6 remote;
 static DAT_IA_ATTR ia_attr;
@@ -192,7 +191,7 @@ static DAT_PROVIDER_ATTR prov_attrs;
 #define CONN_MSG_SIZE 128
 #define CONN_MSG_FMT "%04hx:%08x:%08x:%08x:%s"
 
-void print_usage(void)
+static void print_usage(void)
 {
 	printf("\n dtestx usage \n\n");
 	printf("v: verbose\n");
@@ -240,7 +239,7 @@ static void print_ia_address(struct sockaddr *sa)
 	}
 }
 
-int conn_client_connect(const char *servername, int port)
+static int conn_client_connect(const char *servername, int port)
 {
 
 	struct addrinfo *res, *t;
@@ -283,7 +282,7 @@ int conn_client_connect(const char *servername, int port)
 	return sockfd;
 }
 
-int conn_server_connect(int port)
+static int conn_server_connect(int port)
 {
 	struct addrinfo *res, *t;
 	struct addrinfo hints = {
@@ -499,7 +498,7 @@ static int send_server_params(struct sockaddr *ser_sa)
 	return 0;
 }
 
-void
+static void
 send_msg(void *data,
 	 DAT_COUNT size,
 	 DAT_LMR_CONTEXT context,
@@ -556,19 +555,20 @@ send_msg(void *data,
 			_OK(status, "dat_evd_wait after dat_ep_post_send");
 
 			if (event.event_number != DAT_DTO_COMPLETION_EVENT &&
-			    ud_test && event.event_number != DAT_IB_DTO_EVENT) {
+			    ud_test && event.event_number !=
+			    (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 				printf("unexpected event waiting post_send "
 				       "completion - 0x%x\n",
 				       event.event_number);
 				exit(1);
 			}
-			_OK(dto_event->status, "event status for post_send");
+			_OK((DAT_RETURN)dto_event->status, "event status for post_send");
 		}
 	}
 }
 
 /* RC - Server only, UD - Server and Client, one per EP */
-void process_cr(int idx)
+static void process_cr(int idx)
 {
 	DAT_EVENT event;
 	DAT_COUNT nmore;
@@ -586,8 +586,9 @@ void process_cr(int idx)
 	status = dat_evd_wait(cr_evd, SERVER_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "CR dat_evd_wait");
 
-	if (event.event_number != DAT_CONNECTION_REQUEST_EVENT &&
-	    (ud_test && event.event_number !=
+	if (event.event_number !=
+	    (DAT_EVENT_NUMBER) DAT_CONNECTION_REQUEST_EVENT &&
+	    (ud_test && event.event_number != (DAT_EVENT_NUMBER)
 	     DAT_IB_UD_CONNECTION_REQUEST_EVENT)) {
 		printf("unexpected event,!conn req: 0x%x\n",
 		       event.event_number);
@@ -619,7 +620,7 @@ void process_cr(int idx)
 }
 
 /* RC - Client and Server: 1, UD - Client: 1 per EP, Server: 2 per EP's */
-void process_conn(int idx)
+static void process_conn(int idx)
 {
 	DAT_EVENT event;
 	DAT_COUNT nmore;
@@ -647,7 +648,7 @@ void process_conn(int idx)
 		exp_event = DAT_CONNECTION_EVENT_ESTABLISHED;
 
 	/* Waiting on CR's or CONN_EST */
-	if (event.event_number != exp_event) {
+	if (event.event_number != (DAT_EVENT_NUMBER) exp_event) {
 		printf("unexpected event, !conn established: 0x%x\n",
 		event.event_number);
 		exit(1);
@@ -714,7 +715,7 @@ void process_conn(int idx)
 
 }
 
-int connect_ep(char *hostname, struct sockaddr *ser_sa)
+static int connect_ep(char *hostname, struct sockaddr *ser_sa)
 {
 	DAT_IA_ADDRESS_PTR remote_addr = (DAT_IA_ADDRESS_PTR)&remote;
 	DAT_EP_ATTR ep_attr;
@@ -764,6 +765,7 @@ int connect_ep(char *hostname, struct sockaddr *ser_sa)
 		ep_attr.max_rdma_read_in = 4;
 		ep_attr.max_rdma_read_out = 4;
 	}
+	cookie.as_64 = 0;
 	ep_attr.qos = 0;
 	ep_attr.recv_completion_flags = 0;
 	if (ud_test && !multi_eps)
@@ -987,12 +989,13 @@ no_resolution:
 		_OK(status, "dat_evd_wait for receive message");
 
 		if ((event.event_number != DAT_DTO_COMPLETION_EVENT) &&
-		    (ud_test && event.event_number != DAT_IB_DTO_EVENT)) {
+		    (ud_test && event.event_number !=
+		    (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT)) {
 			printf("unexpected event waiting for RMR context "
 			       "- 0x%x\n", event.event_number);
 			exit(1);
 		}
-		_OK(dto_event->status, "event status for post_recv");
+		_OK((DAT_RETURN)dto_event->status, "event status for post_recv");
 
 		/*
 		 *  multi_eps - receive multi messages on single EP
@@ -1045,7 +1048,7 @@ no_resolution:
 	return (0);
 }
 
-int disconnect_ep(void)
+static int disconnect_ep(void)
 {
 	DAT_RETURN status;
 	DAT_EVENT event;
@@ -1162,7 +1165,7 @@ int disconnect_ep(void)
 	return (0);
 }
 
-int do_immediate()
+static int do_immediate()
 {
 	DAT_EVENT event;
 	DAT_COUNT nmore;
@@ -1210,7 +1213,7 @@ int do_immediate()
 	 */
 	status = dat_evd_wait(dto_evd, DTO_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "dat_evd_wait after dat_ib_post_rdma_write");
-	if (event.event_number != DAT_IB_DTO_EVENT) {
+	if (event.event_number != (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 		printf("unexpected event #0x%x waiting for WR-IMMED #0x%x\n",
 		       event.event_number, DAT_IB_DTO_EVENT);
 		exit(1);
@@ -1218,7 +1221,7 @@ int do_immediate()
 
 	if (nmore)
 		printf("%s() nmore %d\n", __FUNCTION__, nmore);
-	_OK(dto_event->status, "DTO event status");
+	_OK((DAT_RETURN)dto_event->status, "DTO event status");
 	if (ext_event->type == DAT_IB_RDMA_WRITE_IMMED) {
 		if ((dto_event->transfered_length != buf_size) ||
 		    (dto_event->user_cookie.as_64 != 0x9999)) {
@@ -1253,13 +1256,13 @@ int do_immediate()
 	 */
 	status = dat_evd_wait(dto_evd, DTO_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "dat_evd_wait after dat_ib_post_rdma_write");
-	if (event.event_number != DAT_IB_DTO_EVENT) {
+	if (event.event_number != (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 		printf("unexpected event # waiting for WR-IMMED - 0x%x\n",
 		       event.event_number);
 		exit(1);
 	}
 
-	_OK(dto_event->status, "event status");
+	_OK((DAT_RETURN)dto_event->status, "event status");
 	if (ext_event->type == DAT_IB_RDMA_WRITE_IMMED) {
 		if ((dto_event->transfered_length != buf_size) ||
 		    (dto_event->user_cookie.as_64 != 0x9999)) {
@@ -1311,7 +1314,7 @@ int do_immediate()
 	return (0);
 }
 
-int do_cmp_swap()
+static int do_cmp_swap()
 {
 	DAT_DTO_COOKIE cookie;
 	DAT_RETURN status;
@@ -1366,13 +1369,13 @@ int do_cmp_swap()
 	_OK(status, "dat_ib_post_cmp_and_swap");
 	status = dat_evd_wait(dto_evd, DTO_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "dat_evd_wait for compare and swap");
-	if (event.event_number != DAT_IB_DTO_EVENT) {
+	if (event.event_number != (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 		printf("unexpected event after post_cmp_and_swap: 0x%x\n",
 		       event.event_number);
 		exit(1);
 	}
 
-	_OK(dto_event->status, "event status for CMP and SWAP");
+	_OK((DAT_RETURN)dto_event->status, "event status for CMP and SWAP");
 	if (ext_event->type != DAT_IB_CMP_AND_SWAP) {
 		printf("unexpected event data of cmp_swap: type=%d cookie=%d "
 		       "original " F64x "\n",
@@ -1408,7 +1411,7 @@ int do_cmp_swap()
 	return (0);
 }
 
-int do_fetch_add()
+static int do_fetch_add()
 {
 	DAT_DTO_COOKIE cookie;
 	DAT_RETURN status;
@@ -1458,13 +1461,13 @@ int do_fetch_add()
 	_OK(status, "dat_ib_post_fetch_and_add");
 	status = dat_evd_wait(dto_evd, DTO_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "dat_evd_wait for fetch and add");
-	if (event.event_number != DAT_IB_DTO_EVENT) {
+	if (event.event_number != (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 		printf("unexpected event after post_fetch_and_add: 0x%x\n",
 		       event.event_number);
 		exit(1);
 	}
 
-	_OK(dto_event->status, "event status for FETCH and ADD");
+	_OK((DAT_RETURN)dto_event->status, "event status for FETCH and ADD");
 	if (ext_event->type != DAT_IB_FETCH_AND_ADD) {
 		printf("unexpected event data of fetch and add : type=%d "
 		       "cookie=%d original%d\n",
@@ -1501,13 +1504,13 @@ int do_fetch_add()
 
 	status = dat_evd_wait(dto_evd, DTO_TIMEOUT, 1, &event, &nmore);
 	_OK(status, "dat_evd_wait for second fetch and add");
-	if (event.event_number != DAT_IB_DTO_EVENT) {
+	if (event.event_number != (DAT_EVENT_NUMBER) DAT_IB_DTO_EVENT) {
 		printf("unexpected event after second post_fetch_and_add: "
 		       "0x%x\n", event.event_number);
 		exit(1);
 	}
 
-	_OK(dto_event->status, "event status for second FETCH and ADD");
+	_OK((DAT_RETURN)dto_event->status, "event status for second FETCH and ADD");
 	if (ext_event->type != DAT_IB_FETCH_AND_ADD) {
 		printf("unexpected event data of second fetch and add : "
 		       "type=%d cookie=%d original%p\n",
